@@ -3,7 +3,7 @@
 namespace Iranserver\Jobs\OpenStack;
 
 use Iranserver\Base\BaseJob;
-use Iranserver\Models\DTO\StorageDTO;
+use Iranserver\Models\DTO\Openstack\StorageDTO;
 use Iranserver\Models\Interfaces\InfoInterface;
 
 abstract class BaseOpenStackBlockStorageCreateJob extends BaseJob
@@ -19,7 +19,7 @@ abstract class BaseOpenStackBlockStorageCreateJob extends BaseJob
 
     public function __construct(StorageDTO $storageDTO, InfoInterface $info)
     {
-        $this->onConnection(env('QUEUE_CONNECTION','rabbitmq'));
+        $this->onConnection('rabbitmq');
         $this->onQueue('storage.cmd.create');
 
         $this->storageDTO = $storageDTO;
